# Brad

![gh-actions](https://github.com/tcbegley/brad/workflows/Tests/badge.svg)
[![codecov](https://codecov.io/gh/tcbegley/brad/branch/main/graph/badge.svg?token=aJUDsDeu1t)](https://codecov.io/gh/tcbegley/brad)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/brad)
![PyPI - License](https://img.shields.io/pypi/l/brad)

Brad is a Python package for Bootstrap, permutation tests and other resampling
functions.

## Contributing

See the
[contributing guide](https://github.com/tcbegley/brad/blob/main/.github/CONTRIBUTING.md)
for details on how to contribute, run tests, build `brad`, and make releases.
